==> screwdriver-cd-python-sdk-1.0.1.tar.gz: screwdriver-cd-python-sdk-1.0.1/README.md <==
Screwdriver CD Python SDK
=========================

![Python Version][Python Version Badge]
[![Read the Docs][Read the Docs badge]][Read the Docs URL]
[![PyPI][PyPI project badge]][PyPI project url]
[![GitHub Workflow Status][GitHub Workflow Status badge]][GitHub Workflow Status URL]
[![Apache License badge]][Apache License URL]

Documentation
-------------

Coming soon

Troubleshooting
---------------

### PyCharm Doesn't Detect Newly Installed screwdriver-cd-python-sdk

Simply close your project and open it with PyCharm again. The re-indexing should make it work

License
-------

The use and distribution terms for Screwdriver CD Python SDK are covered by the [Apache License, Version 2.0].

<div align="center">
    <a href="https://opensource.org/licenses">
        <img align="center" width="50%" alt="License Illustration" src="https://github.com/QubitPi/QubitPi/blob/master/img/apache-2.png?raw=true">
    </a>
</div>

[Apache License badge]: https://img.shields.io/badge/Apache%202.0-F25910.svg?style=for-the-badge&logo=Apache&logoColor=white
[Apache License URL]: https://www.apache.org/licenses/LICENSE-2.0
[Apache License, Version 2.0]: http://www.apache.org/licenses/LICENSE-2.0.html

[GitHub Workflow Status badge]: https://img.shields.io/github/actions/workflow/status/QubitPi/screwdriver-cd-python-sdk/ci-cd.yml?logo=github&style=for-the-badge
[GitHub Workflow Status URL]: https://github.com/QubitPi/screwdriver-cd-python-sdk/actions/workflows/ci-cd.yml

[Python Version Badge]: https://img.shields.io/badge/Python-3.10-brightgreen?style=for-the-badge&logo=python&logoColor=white
[PyPI project badge]: https://img.shields.io/pypi/v/screwdriver-cd-python-sdk?logo=pypi&logoColor=white&style=for-the-badge
[PyPI project url]: https://pypi.org/project/screwdriver-cd-python-sdk/

[Read the Docs badge]: https://img.shields.io/readthedocs/screwdriver-cd-python-sdk?style=for-the-badge&logo=readthedocs&logoColor=white&label=Read%20the%20Docs&labelColor=8CA1AF
[Read the Docs URL]: https://screwdriver-cd-python-sdk.readthedocs.io/en/latest/

==> screwdriver-cd-python-sdk-1.0.13.tar.gz: screwdriver-cd-python-sdk-1.0.13/README.md <==
Screwdriver CD Python SDK
=========================

![Python Version][Python Version Badge]
[![Read the Docs][Read the Docs badge]][Read the Docs URL]
[![PyPI][PyPI project badge]][PyPI project url]
[![GitHub Workflow Status][GitHub Workflow Status badge]][GitHub Workflow Status URL]
[![Apache License badge]][Apache License URL]

Screwdriver CD Python SDK offers a programmatic approach of interacting with
[Screwdriver API](https://qubitpi.github.io/screwdriver-cd-guide/user-guide/api). For example, it supports

- [Batch creating pipeline jobs](https://screwdriver-cd-python-sdk.readthedocs.io/en/latest/sdk.html#screwdriver_cd_python_sdk.screwdriver_initializer.initialize)
- [Searching pipeline by name](https://screwdriver-cd-python-sdk.readthedocs.io/en/latest/sdk.html#screwdriver_cd_python_sdk.screwdriver_initializer.initialize)
- [Trigger a pipeline build](https://screwdriver-cd-python-sdk.readthedocs.io/en/latest/sdk.html#screwdriver_cd_python_sdk.screwdriver_initializer.initialize)
- etc.

To install the SDK, simply run

```console
pip install screwdriver-cd-python-sdk
```

Please visit [Screwdriver CD Python SDK documentation](https://screwdriver-cd-python-sdk.readthedocs.io/en/latest/) for
more details

License
-------

The use and distribution terms for Screwdriver CD Python SDK are covered by the [Apache License, Version 2.0].

<div align="center">
    <a href="https://opensource.org/licenses">
        <img align="center" width="50%" alt="License Illustration" src="https://github.com/QubitPi/QubitPi/blob/master/img/apache-2.png?raw=true">
    </a>
</div>

[Apache License badge]: https://img.shields.io/badge/Apache%202.0-F25910.svg?style=for-the-badge&logo=Apache&logoColor=white
[Apache License URL]: https://www.apache.org/licenses/LICENSE-2.0
[Apache License, Version 2.0]: http://www.apache.org/licenses/LICENSE-2.0.html

[GitHub Workflow Status badge]: https://img.shields.io/github/actions/workflow/status/QubitPi/screwdriver-cd-python-sdk/ci-cd.yml?logo=github&style=for-the-badge
[GitHub Workflow Status URL]: https://github.com/QubitPi/screwdriver-cd-python-sdk/actions/workflows/ci-cd.yml

[Python Version Badge]: https://img.shields.io/badge/Python-3.10-brightgreen?style=for-the-badge&logo=python&logoColor=white
[PyPI project badge]: https://img.shields.io/pypi/v/screwdriver-cd-python-sdk?logo=pypi&logoColor=white&style=for-the-badge
[PyPI project url]: https://pypi.org/project/screwdriver-cd-python-sdk/

[Read the Docs badge]: https://img.shields.io/readthedocs/screwdriver-cd-python-sdk?style=for-the-badge&logo=readthedocs&logoColor=white&label=Read%20the%20Docs&labelColor=8CA1AF
[Read the Docs URL]: https://screwdriver-cd-python-sdk.readthedocs.io/en/latest/
